# Siemens

This is a placeholder package reserved for a potential [PEP 423](https://peps.python.org/pep-0423)
packaging convention in the future.

For Siemens Open Source projects, see [opensource.siemens.com](https://opensource.siemens.com) and
[github.com/siemens](https://github.com/siemens).
